Release 0.1.8
-------------

* The scheduler no longer needs to be started manually but is spawn
  automatically by the API process. Optionally, the api can be started
  with `--no-scheduler` to prevent the scheduler from being spawn.
